@@ -1,10 +1,8 @@
-# flake8: noqa
 # type: ignore
-__author__ = "Akio Taniguchi"
-__version__ = "0.6.1"
+__version__ = "1.0.0"
 
 
-# for Python 3.7 - 3.8
+# for Python 3.7 and 3.8
 def _make_field_generic():
     from dataclasses import Field
     from typing import Sequence
@@ -19,15 +17,18 @@ _make_field_generic()
 # submodules
 from . import dataarray
 from . import dataset
-from . import deprecated
 from . import datamodel
+from . import dataoptions
 from . import typing
-from . import utils
 
 
 # aliases
 from .dataarray import *
 from .dataset import *
-from .deprecated import *
 from .datamodel import *
+from .dataoptions import *
 from .typing import *
+
+
+# for Sphinx docs
+__all__ = dir()
